This repository contains tools for building coarse-grained polymer models.  These models are designed to interface with OpenMM and PyRosetta.

## To use this repository install it using standard Python conventions:

python setup.py install

## Dependencies:

For a detailed list of dependencies, and more detailed installation instructions, please read the "Installation notes" section of "manual.pdf".

## Testing your installation:

Test your installation by opening a new Python session and typing the following:

import foldamers

**For full documentation please refer to 'manual.pdf'.**
